@@ -63,22 +63,35 @@ class SpecialityChair(Base):
 
 class Subject(Base):
     """
-    Модель "Дисциплина"
+    Дисциплина
     """
-
     __tablename__ = 'univer_subject'
 
+    # Идентификатор
     id = Column('subject_id', Integer, primary_key=True)
+
+    # Тип дисциплины
+    # 0 - Обязательная дисциплина
+    # 1 - Элективная дисциплина
+    # 2 - Практика
+    # 3 - Спец. дисциплина
+    type = Column('subject_type', Integer)
+
+    # Наименование
     name_kz = Column('subject_name_kz', String(500))
     name_ru = Column('subject_name_ru', String(500))
     name_en = Column('subject_name_en', String(500))
+
+    # Описание
     description_kz = Column('subject_description_kz', String)
     description_ru = Column('subject_description_ru', String)
     description_en = Column('subject_description_en', String)
+
+    # Статус
     status = Column(Integer)
 
     def __repr__(self):
-        return '<Subject {}>'.format(self.name_ru)
+        return f'<Subject {self} (id={self.id} status={self.status} type={self.type})>'
 
     def __str__(self):
         return self.name_ru
